@@ -2,7 +2,7 @@
 
 
 import json
-from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, cast
+from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union, cast
 
 import tornado.web
 from wipac_dev_tools import strtobool
@@ -52,7 +52,8 @@ class ArgumentHandler:
     @staticmethod
     def _cast_type(
         value: Any,
-        type_: Type[T],
+        type_: Union[Type[T], Callable[[Any], T]],
+        strict_type: bool = False,
         server_side_error: bool = False,
     ) -> T:
         """Cast `value` to `cast_type` type.
@@ -70,7 +71,11 @@ class ArgumentHandler:
         try:
             if value is None:
                 raise ValueError(
-                    f"value cannot be cast to {type_.__name__} from 'None'"
+                    f"value cannot be cast to '{type_.__name__}' from 'None'"
+                )
+            elif strict_type and not isinstance(value, type_):  # type: ignore[arg-type]
+                raise TypeError(
+                    f"type mismatch: '{type_.__name__}' (value is '{type(value)}')"
                 )
             elif isinstance(value, str) and (type_ == bool) and (value != ""):
                 value = strtobool(value)  # ~> ValueError
@@ -111,15 +116,16 @@ class ArgumentHandler:
         request_body: bytes,
         name: str,
         default: Any,
-        type_: Optional[Type[T]],
+        type_: Union[None, Type[T], Callable[[Any], T]],
         choices: Optional[List[Any]],
         forbiddens: Optional[List[Any]],
+        strict_type: bool,
     ) -> T:
         """Get argument from the JSON-decoded request-body."""
         try:  # first, assume arg is required
             value = _parse_json_body_arguments(request_body)[name]
             if type_:
-                value = ArgumentHandler._cast_type(value, type_)
+                value = ArgumentHandler._cast_type(value, type_, strict_type)
             return ArgumentHandler._validate_choice(value, choices, forbiddens)
         except (KeyError, json.decoder.JSONDecodeError):
             # Required -> raise 400
@@ -141,9 +147,10 @@ class ArgumentHandler:
         name: str,
         default: Any,
         strip: bool,
-        type_: Optional[Type[T]],
+        type_: Union[None, Type[T], Callable[[Any], T]],
         choices: Optional[List[Any]],
         forbiddens: Optional[List[Any]],
+        strict_type: bool,
     ) -> T:
         """Get argument from query base-arguments / JSON-decoded request-body.
 
@@ -155,7 +162,13 @@ class ArgumentHandler:
             # check JSON-body arguments
             try:
                 return ArgumentHandler.get_json_body_argument(
-                    request_body, name, NO_DEFAULT, type_, choices, forbiddens
+                    request_body,
+                    name,
+                    NO_DEFAULT,
+                    type_,
+                    choices,
+                    forbiddens,
+                    strict_type,
                 )
             except tornado.web.MissingArgumentError:
                 pass
@@ -166,7 +179,7 @@ class ArgumentHandler:
                 str_val = rest_handler_get_argument(name, strip=strip)
                 if type_:
                     return ArgumentHandler._validate_choice(
-                        ArgumentHandler._cast_type(str_val, type_),
+                        ArgumentHandler._cast_type(str_val, type_, strict_type),
                         choices,
                         forbiddens,
                     )
@@ -181,11 +194,19 @@ class ArgumentHandler:
 
         # Else: Optional (aka use default value)
         if default is not None and type_:
-            ArgumentHandler._cast_type(default, type_, server_side_error=True)
+            ArgumentHandler._cast_type(
+                default, type_, strict_type, server_side_error=True
+            )
         # check JSON-body arguments
         try:  # DON'T pass `default` b/c we want to know if there ISN'T a value
             return ArgumentHandler.get_json_body_argument(
-                request_body, name, NO_DEFAULT, type_, choices, forbiddens
+                request_body,
+                name,
+                NO_DEFAULT,
+                type_,
+                choices,
+                forbiddens,
+                strict_type,
             )
         except tornado.web.MissingArgumentError:
             pass  # OK. Next, we'll try query base-arguments...
@@ -196,7 +217,7 @@ class ArgumentHandler:
             str_val = rest_handler_get_argument(name, default, strip=strip)
             if type_:
                 return ArgumentHandler._validate_choice(
-                    ArgumentHandler._cast_type(str_val, type_),
+                    ArgumentHandler._cast_type(str_val, type_, strict_type),
                     choices,
                     forbiddens,
                 )
